@@ -2,7 +2,6 @@ import curses, textwrap, traceback
 
 
 class Pager:
-
     def __init__(
         self,
         text: list,
@@ -18,17 +17,17 @@ class Pager:
         space_after_separator: bool = True,
         title_text: str = "",
         center_title: bool = False,
-        title_bg: str = "-",
         title_fg: str = "-",
+        title_bg: str = "-",
         overflow_indicator: str = ">",
         overflow_indicator_fg: str = "black",
         overflow_indicator_bg: str = "white",
         end_text: str = "(END)",
-        end_fg: str = "black",
-        end_bg: str = "white",
+        end_text_fg: str = "black",
+        end_text_bg: str = "white",
         bottom_bar_text: str = "Quit(q) Help(h)",
-        bottom_bar_bg: str = "white",
         bottom_bar_fg: str = "black",
+        bottom_bar_bg: str = "white",
         show_cursor_y_position: bool = True,
         show_cursor_y_percentage: bool = True,
         blink: bool = False,
@@ -50,17 +49,17 @@ class Pager:
         self.space_after_separator = space_after_separator
         self.title_text = title_text
         self.center_title = center_title
-        self.title_bg = title_bg
         self.title_fg = title_fg
+        self.title_bg = title_bg
         self.overflow_indicator = overflow_indicator
         self.overflow_indicator_fg = overflow_indicator_fg
         self.overflow_indicator_bg = overflow_indicator_bg
         self.end_text = end_text
-        self.end_fg = end_fg
-        self.end_bg = end_bg
+        self.end_text_fg = end_text_fg
+        self.end_text_bg = end_text_bg
         self.bottom_bar_text = bottom_bar_text
-        self.bottom_bar_bg = bottom_bar_bg
         self.bottom_bar_fg = bottom_bar_fg
+        self.bottom_bar_bg = bottom_bar_bg
         self.show_cursor_y_position = show_cursor_y_position
         self.show_cursor_y_percentage = show_cursor_y_percentage
         self.blink = [
@@ -93,7 +92,7 @@ class Pager:
         }
 
         curses.init_pair(
-            2, curses_colors[self.end_fg], curses_colors[self.end_bg]
+            2, curses_colors[self.end_text_fg], curses_colors[self.end_text_bg]
         )  # color for self.end_text
         curses.init_pair(
             3,
@@ -237,20 +236,6 @@ class Pager:
                                 cursor_x : cursor_x + free_space_for_text
                             ]
                         )
-                        if (
-                            self.show_overflow_indicator
-                            and cursor_x + free_space_for_text
-                            < len(self.text[line_index])
-                        ):
-                            # there is at least one character that didn't fit to screen (overflowing from right side)
-                            scr.addstr(
-                                len(self.title_text.splitlines()) + i,
-                                width
-                                - len(self.overflow_indicator)
-                                - self.right_padding_for_text,
-                                self.overflow_indicator,
-                                curses.color_pair(8),
-                            )
 
                     else:
                         # search is activated
@@ -281,6 +266,20 @@ class Pager:
                                     # char isn't inside of any find_str
                                     scr.addstr(char)
 
+                    if (
+                        self.show_overflow_indicator
+                        and cursor_x + free_space_for_text < len(self.text[line_index])
+                    ):
+                        # there is at least one character that didn't fit to screen (overflowing from right side)
+                        scr.addstr(
+                            len(self.title_text.splitlines()) + i,
+                            width
+                            - len(self.overflow_indicator)
+                            - self.right_padding_for_text,
+                            self.overflow_indicator,
+                            curses.color_pair(8),
+                        )
+
                 else:
                     # we displayed last line of self.text but there is still a gap between last line and bottom bar
                     if line_index == len_text:
@@ -325,7 +324,7 @@ class Pager:
                 bottom_bar_text
                 + " " * (width - len(bottom_bar_text) - len(bottom_bar_cursor_datas))
                 + bottom_bar_cursor_datas,
-                curses.color_pair(3) + curses.A_BOLD + curses.A_DIM,
+                curses.color_pair(3),
             )
             # we are using insstr() because addstr() does not allow filling the entire line if we are using getch() after it
 
@@ -627,7 +626,7 @@ class Pager:
                 bottom_text
                 + " " * (width - len(bottom_text) - len(cursor_y_pos_text))
                 + cursor_y_pos_text,
-                curses.color_pair(3) + curses.A_DIM,
+                curses.color_pair(3),
             )
 
             scr.refresh()
